@@ -155,9 +155,9 @@ void ProgressDialog::error( TQString text )
         TDEApplication::setOverrideCursor( TQt::waitCursor );
         m_timer->start( TIMER_INTERVAL );
     }
-    
+
     //TODO: simplify this (breaks i18n)
-    TDEListViewItem* item = new TDEListViewItem( display, TQString( i18n("Error: %1") ).arg( TQString() ) + simplify( text ), count() );
+    TDEListViewItem* item = new TDEListViewItem( display, i18n("Error: %1").arg( TQString() ) + simplify( text ), count() );
     item->setPixmap( 0, SmallIcon("cancel") );
     display->insertItem( item );
 }
@@ -169,10 +169,10 @@ void ProgressDialog::warning( TQString text )
         TDEApplication::setOverrideCursor( TQt::waitCursor );
         m_timer->start( TIMER_INTERVAL );
     }
-    
-    TDEListViewItem* item = new TDEListViewItem( display, TQString( i18n("Warning: %1") ).arg( TQString() ) + simplify( text ), count() );
+
+    TDEListViewItem* item = new TDEListViewItem( display, i18n("Warning: %1").arg( TQString() ) + simplify( text ), count() );
     item->setPixmap( 0, SmallIcon("idea") );
-    display->insertItem( item );    
+    display->insertItem( item );
 }
 
 void ProgressDialog::quitAll()
@@ -350,3 +350,5 @@ void ProgressDialog::slotTimer()
 {
     kapp->processEvents( 0 );
 }
+
+#include "ProgressDialog.moc"
