@@ -137,7 +137,7 @@ TQString CommandPlugin::processFile( BatchRenamer* b, int i, TQString, int )
     proc.resume();
 
     if( !noblock && proc.exitStatus() )
-        return command.arg( filename ) + TQString( i18n(" exited with error: %1") ).arg( proc.exitStatus() );
+        return command.arg( filename ) + i18n(" exited with error: %1").arg( proc.exitStatus() );
 
     return TQString();
 }
@@ -189,3 +189,4 @@ const TQPixmap CommandPlugin::getIcon() const
     return kapp->iconLoader()->loadIcon( "konsole", TDEIcon::Small );
 }
 
+#include "commandplugin.moc"
