@@ -88,7 +88,7 @@ TQString DatePlugin::processFile(BatchRenamer* b, int i, TQString token, int )
         return tmp.sprintf("%0*i", 2, t.second() );
     else {
         TDEIO::UDSEntry entry;
-        TDEIO::NetAccess::stat( b->files()[i].src.url, entry );
+        TDEIO::NetAccess::stat(b->files()[i].src.url, entry, 0);
         KFileItem item( entry, b->files()[i].src.url );
         if( token == "user" )
             return item.user();
@@ -151,3 +151,5 @@ void DatePlugin::addHelp( HelpDialogData* data )
 
     data->add( getName(), &list, getIcon() );
 }
+
+#include "dateplugin.moc"
